@@ -34,10 +34,24 @@ class StrictDocSemanticError(Exception):
         )
 
     @staticmethod
-    def unregistered_field(field_name, line=None, col=None, filename=None):
+    def unregistered_field(
+        *,
+        field_name: str,
+        requirement: Requirement,
+        document_grammar: DocumentGrammar,
+        line=None,
+        col=None,
+        filename=None,
+    ):
+        grammar_dump = document_grammar.dump_fields(
+            requirement.requirement_type
+        )
         return StrictDocSemanticError(
             title=f"Invalid requirement field: {field_name}",
-            hint=None,
+            hint=(
+                f"Compare with the document grammar: [{grammar_dump}] "
+                f"for type: {requirement.requirement_type}"
+            ),
             example=None,
             line=line,
             col=col,
@@ -45,19 +59,26 @@ class StrictDocSemanticError(Exception):
         )
 
     @staticmethod
-    def missing_required_field(
+    def missing_required_field(  # pylint: disable=too-many-arguments
         requirement: Requirement,
         grammar_field: GrammarElementField,
+        document_grammar: DocumentGrammar,
         line=None,
         col=None,
         filename=None,
     ):
+        grammar_fields = document_grammar.dump_fields(
+            requirement.requirement_type
+        )
         return StrictDocSemanticError(
             title=(
                 f"Requirement is missing a field that is required by "
                 f"grammar: {grammar_field.title}"
             ),
-            hint=f"Requirement fields: [{requirement.dump_fields()}]",
+            hint=(
+                f"Requirement fields: [{requirement.dump_fields()}], "
+                f"Grammar fields: [{grammar_fields}]"
+            ),
             example=None,
             line=line,
             col=col,
@@ -73,7 +94,7 @@ class StrictDocSemanticError(Exception):
         col=None,
         filename=None,
     ):
-        grammar_dump = document_grammar.dump_fields(
+        grammar_fields = document_grammar.dump_fields(
             requirement.requirement_type
         )
         return StrictDocSemanticError(
@@ -83,7 +104,7 @@ class StrictDocSemanticError(Exception):
             ),
             hint=(
                 f"Requirement fields: [{requirement.dump_fields()}], "
-                f"Grammar fields: [{grammar_dump}]"
+                f"Grammar fields: [{grammar_fields}]"
             ),
             example=None,
             line=line,
