@@ -11,7 +11,6 @@ class SDocObjectFactory:
     @staticmethod
     def create_document(title: Optional[str]):
         return Document(
-            name=None,
             title=title if title else "NONAME",
             config=None,
             grammar=None,
@@ -43,7 +42,6 @@ class SDocObjectFactory:
                     field_value=uid,
                     field_value_multiline=None,
                     field_value_references=None,
-                    field_value_special_fields=None,
                 )
             )
         if level:
@@ -55,7 +53,6 @@ class SDocObjectFactory:
                     field_value=level,
                     field_value_multiline=None,
                     field_value_references=None,
-                    field_value_special_fields=None,
                 )
             )
         if title:
@@ -66,7 +63,6 @@ class SDocObjectFactory:
                     field_value=title,
                     field_value_multiline=None,
                     field_value_references=None,
-                    field_value_special_fields=None,
                 )
             )
         if statement:
@@ -77,7 +73,6 @@ class SDocObjectFactory:
                     field_value=statement,
                     field_value_multiline=None,
                     field_value_references=None,
-                    field_value_special_fields=None,
                 )
             )
         if statement_multiline:
@@ -91,7 +86,6 @@ class SDocObjectFactory:
                     field_value=None,
                     field_value_multiline=statement_multiline,
                     field_value_references=None,
-                    field_value_special_fields=None,
                 )
             )
         if rationale:
@@ -102,7 +96,6 @@ class SDocObjectFactory:
                     field_value=rationale,
                     field_value_multiline=None,
                     field_value_references=None,
-                    field_value_special_fields=None,
                 )
             )
         if rationale_multiline:
@@ -113,7 +106,6 @@ class SDocObjectFactory:
                     field_value=None,
                     field_value_multiline=rationale_multiline,
                     field_value_references=None,
-                    field_value_special_fields=None,
                 )
             )
         if tags is not None:
@@ -125,7 +117,6 @@ class SDocObjectFactory:
                     field_value=tags,
                     field_value_multiline=None,
                     field_value_references=None,
-                    field_value_special_fields=None,
                 )
             )
         if comments is not None:
@@ -139,7 +130,6 @@ class SDocObjectFactory:
                         field_value=None,
                         field_value_multiline=comment,
                         field_value_references=None,
-                        field_value_special_fields=None,
                     )
                 )
         return Requirement(
