@@ -1,5 +1,6 @@
 from typing import Optional, List
 
+from strictdoc.backend.sdoc.document_reference import DocumentReference
 from strictdoc.backend.sdoc.models.node import Node
 
 
@@ -27,9 +28,8 @@ class Section(Node):  # pylint: disable=too-many-instance-attributes
         self.section_contents = section_contents
 
         self.ng_level = None
-        self.ng_sections = []
         self.ng_has_requirements = False
-        self.ng_document_reference = None
+        self.ng_document_reference: Optional[DocumentReference] = None
         self.context = SectionContext()
 
     def __str__(self):
