@@ -1,5 +1,7 @@
 import argparse
 import os
+import sys
+from enum import Enum
 
 EXPORT_FORMATS = ["html", "html-standalone", "rst", "excel", "reqif-sdoc"]
 
@@ -242,6 +244,12 @@ class PassthroughCommandConfig:
         self.output_file = output_file
 
 
+class ExportMode(Enum):
+    DOCTREE = 1
+    STANDALONE = 2
+    DOCTREE_AND_STANDALONE = 3
+
+
 class ExportCommandConfig:  # pylint: disable=too-many-instance-attributes
     def __init__(  # pylint: disable=too-many-arguments
         self,
@@ -268,6 +276,37 @@ class ExportCommandConfig:  # pylint: disable=too-many-instance-attributes
         )
         self.output_html_root: str = os.path.join(output_dir, "html")
 
+    def get_export_mode(self):
+        if "html" in self.formats:
+            if "html-standalone" in self.formats:
+                return ExportMode.DOCTREE_AND_STANDALONE
+            return ExportMode.DOCTREE
+        if "html-standalone" in self.formats:
+            return ExportMode.STANDALONE
+        raise NotImplementedError
+
+    def get_static_files_path(self):
+        if getattr(sys, "frozen", False):
+            # If the application is run as a bundle, the PyInstaller bootloader
+            # extends the sys module by a flag frozen=True and sets the app
+            # path into variable _MEIPASS'.
+            bundle_dir = sys._MEIPASS  # pylint: disable=protected-access
+            return os.path.join(bundle_dir, "_static")
+        return os.path.join(
+            self.strictdoc_root_path, "strictdoc/export/html/_static"
+        )
+
+    def get_extra_static_files_path(self):
+        if getattr(sys, "frozen", False):
+            # If the application is run as a bundle, the PyInstaller bootloader
+            # extends the sys module by a flag frozen=True and sets the app
+            # path into variable _MEIPASS'.
+            bundle_dir = sys._MEIPASS  # pylint: disable=protected-access
+            return os.path.join(bundle_dir, "_static_extra")
+        return os.path.join(
+            self.strictdoc_root_path, "strictdoc/export/html/_static_extra"
+        )
+
 
 class DumpGrammarCommandConfig:
     def __init__(self, output_file):
