@@ -6,13 +6,12 @@ from strictdoc.core.file_traceability_index import FileTraceabilityIndex
 from strictdoc.helpers.sorting import alphanumeric_sort
 
 
-class TraceabilityIndex:  # pylint: disable=too-many-public-methods
+class TraceabilityIndex:  # pylint: disable=too-many-public-methods, too-many-instance-attributes  # noqa: E501
     def __init__(  # pylint: disable=too-many-arguments
         self,
         document_iterators,
         requirements_parents,
         tags_map,
-        documents_ref_depth_map,
         document_parents_map,
         document_children_map,
         file_traceability_index: FileTraceabilityIndex,
@@ -20,11 +19,14 @@ class TraceabilityIndex:  # pylint: disable=too-many-public-methods
         self._document_iterators = document_iterators
         self._requirements_parents = requirements_parents
         self._tags_map = tags_map
-        self._documents_ref_depth_map = documents_ref_depth_map
         self._document_parents_map = document_parents_map
         self._document_children_map = document_children_map
         self._file_traceability_index = file_traceability_index
 
+        self.document_tree = None
+        self.asset_dirs = None
+        self.strictdoc_last_update = None
+
     def has_requirements(self):
         return len(self.requirements_parents.keys()) > 0
 
@@ -40,10 +42,6 @@ class TraceabilityIndex:  # pylint: disable=too-many-public-methods
     def tags_map(self):
         return self._tags_map
 
-    @property
-    def documents_ref_depth_map(self):
-        return self._documents_ref_depth_map
-
     def get_document_iterator(self, document):
         return self.document_iterators[document]
 
@@ -113,21 +111,21 @@ class TraceabilityIndex:  # pylint: disable=too-many-public-methods
 
     def get_link(self, requirement):
         document = self.requirements_parents[requirement.uid]["document"]
-        return f"{document.name} - Traceability.html#{requirement.uid}"
+        return f"{document.title} - Traceability.html#{requirement.uid}"
 
     def get_deep_link(self, requirement):
         document = self.requirements_parents[requirement.uid]["document"]
-        return f"{document.name} - Traceability Deep.html#{requirement.uid}"
+        return f"{document.title} - Traceability Deep.html#{requirement.uid}"
 
     def has_tags(self, document):
-        if document.name not in self.tags_map:
+        if document.title not in self.tags_map:
             return False
-        tags_bag = self.tags_map[document.name]
+        tags_bag = self.tags_map[document.title]
         return len(tags_bag.keys())
 
     def get_tags(self, document):
-        assert document.name in self.tags_map
-        tags_bag = self.tags_map[document.name]
+        assert document.title in self.tags_map
+        tags_bag = self.tags_map[document.title]
         if not tags_bag:
             yield []
             return
@@ -136,9 +134,6 @@ class TraceabilityIndex:  # pylint: disable=too-many-public-methods
         for tag in tags:
             yield tag, tags_bag[tag]
 
-    def get_max_ref_depth(self, document):
-        return self.documents_ref_depth_map[document]
-
     def get_requirement_file_links(self, requirement):
         return self._file_traceability_index.get_requirement_file_links(
             requirement
