@@ -1,27 +1,23 @@
-from jinja2 import Environment, PackageLoader, StrictUndefined
-
 from strictdoc.cli.cli_arg_parser import ExportCommandConfig
 from strictdoc.core.document_tree_iterator import DocumentTreeIterator
 from strictdoc.core.traceability_index import TraceabilityIndex
 from strictdoc.export.html.document_type import DocumentType
 from strictdoc.export.html.renderers.markup_renderer import MarkupRenderer
+from strictdoc.export.html.html_templates import HTMLTemplates
 
 
 class RequirementsCoverageHTMLGenerator:
-    env = Environment(
-        loader=PackageLoader("strictdoc", "export/html/templates"),
-        undefined=StrictUndefined,
-    )
-    env.globals.update(isinstance=isinstance)
+    env = HTMLTemplates.jinja_environment
 
     @staticmethod
     def export(
         config: ExportCommandConfig,
-        document_tree,
         traceability_index: TraceabilityIndex,
         link_renderer,
     ):
-        document_tree_iterator = DocumentTreeIterator(document_tree)
+        document_tree_iterator = DocumentTreeIterator(
+            traceability_index.document_tree
+        )
 
         output = ""
 
@@ -37,7 +33,6 @@ class RequirementsCoverageHTMLGenerator:
         )
         output += template.render(
             config=config,
-            document_tree=document_tree,
             traceability_index=traceability_index,
             documents_iterator=document_tree_iterator.iterator(),
             link_renderer=link_renderer,
